src
===

Boundary
--------

.. doxygenclass:: sme::mesh::Boundary

ContourMap
----------

.. doxygenclass:: sme::mesh::ContourMap

.. doxygenstruct:: sme::mesh::Contours

getInteriorPoints
-----------------

.. doxygenfunction:: sme::mesh::getInteriorPoints

Line Simplifier
---------------

.. doxygenclass:: sme::mesh::LineSimplifier

.. doxygenstruct:: sme::mesh::LineError

PixelCornerIterator
-------------------

.. doxygenclass:: sme::mesh::PixelCornerIterator

Triangulate
-----------

.. doxygenclass:: sme::mesh::Triangulate
